#!/env/python3
#
#  Usage: python main.py <FILE_OR_FOLDER> [OUTPUT_FILENAME [MAIN_TITLE]]
#

import os
import sys
import csv

from robot.api import TestSuiteBuilder

import testspec
import config
import lib


def is_interface_heading(ref):
    return ref.lvl() == 3


def is_endpoint_heading(ref):
    return ref.lvl() == 4

def create_sol_002(sol_002_root, commit_id, output_dir):

    sol002_index = None

    myf = open('sol_002_tree_ok.csv', 'r')
    sol002_index = csv.reader(myf)

    if sol002_index is None:
        print("ERROR OPENING SOL002 INDEX")
        return

    spec = testspec.TestSpec()
    current_folder = None

    for row in sol002_index:
        if len(row) < 3:
            continue

        ref = lib.DocReference.from_str(row[0].strip())

        if is_interface_heading(ref):
            spec.add_heading_from_ref(row[1].strip(), ref)
            current_folder = row[2].strip()

        elif is_endpoint_heading(ref):
            suite = TestSuiteBuilder().build(os.path.join(sol_002_root, current_folder, row[2].strip()))
            lib.gen_api_suite(ref, suite, spec, current_folder, commit_id, "SOL002")

    outfn = os.path.join(output_dir,"SOL002_attachment.docx")
    print("Writing SOL 002 definitions to: ", outfn)
    spec.save(outfn)


if __name__ == "__main__":

    if len(sys.argv) < 2:
        print("Usage: robot2doc <sol_robot_root_dir> commit-id")
        sys.exit(-1)

    ROOT = sys.argv[1]
    COMMIT_ID = sys.argv[2] if len(sys.argv) > 2 else None

    print("Received arguments: ", sys.argv)

    print("Generating entire SOL tests")

    create_sol_002(os.path.join(ROOT, "SOL002"), COMMIT_ID, "..")